summaryrefslogtreecommitdiff
path: root/src/settings.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/settings.h')
-rw-r--r--src/settings.h13
1 files changed, 10 insertions, 3 deletions
diff --git a/src/settings.h b/src/settings.h
index 484ce163..e7ad7317 100644
--- a/src/settings.h
+++ b/src/settings.h
@@ -626,10 +626,17 @@ public:
bool collapsibleSeparators(Qt::SortOrder order) const;
void setCollapsibleSeparators(bool ascending, bool descending);
// whether to display mod conflicts on separators when collapsed
//
- bool collapsibleSeparatorsConflicts() const;
- void setCollapsibleSeparatorsConflicts(bool b);
+ bool collapsibleSeparatorsHighlightTo() const;
+ void setCollapsibleSeparatorsHighlightTo(bool b);
+
+ // whether to highlight mod conflicts and plugins from separators
+ // when selected but collapsed
+ //
+ bool collapsibleSeparatorsHighlightFrom() const;
+ void setCollapsibleSeparatorsHighlightFrom(bool b);
// whether each profile should have its own expansion state
//
@@ -626,10 +626,17 @@ public:
bool collapsibleSeparators(Qt::SortOrder order) const;
void setCollapsibleSeparators(bool ascending, bool descending);
- // whether to display mod conflicts on separators when collapsed
+ // whether to highlight mod conflicts and plugins on collapsed
+ // separators
//